#!/usr/bin/env python
from googleapiclient.discovery import build
import os
from dotenv import load_dotenv

def search_youtube_url(query):
    load_dotenv()
    api_key = os.getenv('YOUTUBE_API_KEY')
    print(f"API Key: {api_key}")
    youtube = build('youtube', 'v3', developerKey=api_key)
    request = youtube.search().list(
        part="snippet",
        maxResults=1,
        q=query
    )
    response = request.execute()
    if not response['items']:
        return "No video found"
    video_id = response['items'][0]['id']['videoId']
    video_url = f"https://www.youtube.com/watch?v={video_id}"
    return video_url

if __name__ == "__main__":
    query = "Could an orca give a TED Talk?"
    print(search_youtube_url(query))



from setuptools import setup, find_packages

with open('requirements.txt') as f:
    requirements = [line.strip() for line in f.readlines()]

setup(
    name="search-youtube-url",
    version="1.0.0",
    packages=find_packages(),
    py_modules=['search_youtube_url'],
    install_requires=requirements,
    entry_points={
        'console_scripts': [
            'search_youtube_url = search_youtube_url:main',
        ],
    },
    long_description=open('README.md', 'r').read(),
    long_description_content_type='text/markdown',)
